# PiPy Version 
[![inforion package in InforION feed in Azure Artifacts](https://feeds.dev.azure.com/InforOS/51c0aec5-707a-42f9-9da0-3b7fd2b0ee44/_apis/public/Packaging/Feeds/72272382-59ae-4dc6-8b95-0d937e37ba83/Packages/34eafa2d-5696-4565-be85-7acecf84623c/Badge)](https://dev.azure.com/InforOS/InforION/_packaging?_a=package&feed=72272382-59ae-4dc6-8b95-0d937e37ba83&package=34eafa2d-5696-4565-be85-7acecf84623c&preferRelease=true)

# Current Build Status

[![Build Status](https://dev.azure.com/InforOS/InforION/_apis/build/status/dajor.inforion?branchName=master)](https://dev.azure.com/InforOS/InforION/_build/latest?definitionId=2&branchName=master)



This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.
